#
# Conditional build:
%bcond_without	tests	# don't perform make check
#
Summary:	Multiple-precision floating-point computations library
Summary(pl.UTF-8):	Biblioteka obliczeń zmiennoprzecinkowych wielokrotnej precyzji
Name:		mpfr
Version:	4.2.1
Release:	1
License:	LGPL v3+
Group:		Libraries
Source0:	https://www.mpfr.org/mpfr-current/%{name}-%{version}.tar.xz
# Source0-md5:	523c50c6318dde6f9dc523bc0244690a
Patch0:		%{name}-info.patch
URL:		https://www.mpfr.org/
BuildRequires:	autoconf >= 2.50
BuildRequires:	autoconf-archive
BuildRequires:	automake >= 1:1.13
BuildRequires:	gmp-devel >= 5.0
BuildRequires:	libtool
BuildRequires:	tar >= 1:1.22
BuildRequires:	texinfo
BuildRequires:	xz
Requires:	gmp >= 5.0
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
The MPFR library is a C library for multiple-precision floating-point
computations with exact rounding (also called correct rounding). It is
based on the GMP multiple-precision library. The main goal of MPFR is
to provide a library for multiple-precision floating-point computation
which is both efficient and has a well-defined semantics. It copies
the good ideas from the ANSI/IEEE-754 standard for double-precision
floating-point arithmetic (53-bit mantissa).

%description -l pl.UTF-8
Biblioteka MPFR to biblioteka C do obliczeń zmiennoprzecinkowych z
wielokrotną precyzją i dokładnym zaokrąglaniem (zwanym także poprawnym
zaokrąglaniem). Jest oparta na bibliotece GMP wielokrotnej precyzji.
Głównym celem MPFR jest dostarczenie biblioteki do obliczeń
zmiennoprzecinkowych wielokrotnej precyzji, która jest wydajna i ma
dobrze zdefiniowaną semantykę. Powiela dobre idee ze standardu
ANSI/IEEE-754 dla arytmetyki zmiennoprzecinkowej podwójnej precyzji (z
53-bitową mantysą).

%package devel
Summary:	Header files for MPFR library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki MPFR
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	gmp-devel >= 5.0
Obsoletes:	libmpfr-devel < 4.2

%description devel
Header files for MPFR library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki MPFR.

%package static
Summary:	Static MPFR library
Summary(pl.UTF-8):	Statyczna biblioteka MPFR
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static MPFR library.

%description static -l pl.UTF-8
Statyczna biblioteka MPFR.

%prep
%setup -q
%patch0 -p1

# triggers bug in gold (as of binutils-2.21.53.0.2-1.i686)
mkdir my-ld
if [ -x /usr/bin/ld.bfd ]; then
	ln -s /usr/bin/ld.bfd my-ld/ld
fi

%build
export PATH=$PWD/my-ld:$PATH
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__automake}
%configure \
	--enable-shared

# make -j4 creates truncated .lo files
%{__make} -j1 all

%if %{with tests}
%{__make} check
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libmpfr.la
# move to PLD specific place
install -d $RPM_BUILD_ROOT%{_examplesdir}
%{__mv} $RPM_BUILD_ROOT%{_docdir}/mpfr/examples $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
# packaged as %doc
%{__rm} $RPM_BUILD_ROOT%{_docdir}/mpfr/*

rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%post	devel -p /sbin/postshell
-/usr/sbin/fix-info-dir -c %{_infodir}

%postun	devel -p /sbin/postshell
-/usr/sbin/fix-info-dir -c %{_infodir}

%files
%defattr(644,root,root,755)
%doc AUTHORS BUGS ChangeLog NEWS README TODO doc/FAQ.html
%attr(755,root,root) %{_libdir}/libmpfr.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libmpfr.so.6

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libmpfr.so
%{_includedir}/mpfr.h
%{_includedir}/mpf2mpfr.h
%{_pkgconfigdir}/mpfr.pc
%{_infodir}/mpfr.info*
%{_examplesdir}/%{name}-%{version}

%files static
%defattr(644,root,root,755)
%{_libdir}/libmpfr.a
%changelog
* Sun Sep 03 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/mpfr.git;a=log;h=master

* Sun Sep 03 2023 Jakub Bogusz <qboosh@pld-linux.org> d2f8c07
- updated to 4.2.1

* Wed Feb 22 2023 Jan Palus <atler@pld-linux.org> b15615b
- up to 4.2.0

* Sun Dec 11 2022 Jakub Bogusz <qboosh@pld-linux.org> d096e38
- updated to 4.1.1

* Wed May 05 2021 Marcin Krol <hawk@tld-linux.org> bddd550
- rediffed

* Sat Nov 14 2020 Jan Palus <atler@pld-linux.org> d162606
- BR: autoconf-archive for AX_PTHREAD

* Mon Jul 20 2020 Jakub Bogusz <qboosh@pld-linux.org> 9227275
- updated to 4.1.0

* Sat Feb 23 2019 Jakub Bogusz <qboosh@pld-linux.org> e964a19
- updated to 4.0.2

* Sun Apr 01 2018 Jakub Bogusz <qboosh@pld-linux.org> ca577b0
- updated to 4.0.1 (note: new soname)

* Wed Dec 06 2017 Jakub Bogusz <qboosh@pld-linux.org> cfdb3d4
- updated to 3.1.6

* Tue Oct 25 2016 Jakub Bogusz <qboosh@pld-linux.org> 31eee35
- updated to 3.1.5

* Mon Mar 07 2016 Jakub Bogusz <qboosh@pld-linux.org> 7b53ff3
- updated to 3.1.4

* Sun Jun 28 2015 Jakub Bogusz <qboosh@pld-linux.org> 2ec974b
- updated to 3.1.3

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> 65ab791
- x32 rebuild
- release 2 (by relup.sh)

* Thu Mar 14 2013 Jakub Bogusz <qboosh@pld-linux.org> c7da301
- updated am version

* Thu Mar 14 2013 Paweł Sikora <pawel.sikora@agmk.net> 7341c37
- updated to 3.1.2.

* Thu Jul 05 2012 Jakub Bogusz <qboosh@pld-linux.org> 2a39850
- updated to 3.1.1
- removed obsolete automake-1_12 patch

* Mon Jun 18 2012 Jacek Konieczny <jajcus@pld-linux.org> 6073c9e
- automake 1.12 patch

* Wed Oct 12 2011 Jakub Bogusz <qboosh@pld-linux.org> 5fae08a
- updated to 3.1.0
- force ld.bfd as it triggers internal error in gold (related to TLS support)

* Thu Apr 21 2011 Jakub Bogusz <qboosh@pld-linux.org> 1261df1
- updated to 3.0.1

* Sun Jun 13 2010 Jakub Bogusz <qboosh@pld-linux.org> 31543a7
- updated to 3.0.0 (note: new soname, LGPL v3 now)

